@@ -85,6 +85,8 @@
 #ifdef HAVE_PTHREAD
 # define CHEROKEE_MUTEX_T(n)          pthread_mutex_t n
 # define CHEROKEE_RWLOCK_T(n)         pthread_rwlock_t n
+# define CHEROKEE_THREAD_JOIN(t)      pthread_join(t,NULL)
+# define CHEROKEE_THREAD_SELF         pthread_self()
 
 # define CHEROKEE_MUTEX_LOCK(m)       pthread_mutex_lock(m)
 # define CHEROKEE_MUTEX_UNLOCK(m)     pthread_mutex_unlock(m)
@@ -102,6 +104,8 @@
 #else
 # define CHEROKEE_MUTEX_T(n)          
 # define CHEROKEE_RWLOCK_T(n)         
+# define CHEROKEE_THREAD_JOIN(t)
+# define CHEROKEE_THREAD_SELF         0
 
 # define CHEROKEE_MUTEX_LOCK(m)
 # define CHEROKEE_MUTEX_UNLOCK(m)
@@ -120,14 +124,11 @@
 
 #ifdef _WIN32
 # define SOCK_ERRNO()      WSAGetLastError()
-# define CLOSE_ON_EXEC(h)  ((void)0)
 #else
 # define SOCK_ERRNO()      errno
-# define CLOSE_ON_EXEC(h)  fcntl (h, F_SETFD, FD_CLOEXEC)
 #endif
 
 
-
 /* IMPORTANT:
  * Cross compilers should define BYTE_ORDER in CFLAGS 
  */
