@@ -8,7 +8,7 @@
  * This piece of code by:
  *      Miguel Angel Ajo Pelayo <ajo@godsmaze.org>
  *
- * Copyright (C) 2001-2006 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2008 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -34,15 +34,13 @@
 
 #include <cherokee/common.h>
 #include <cherokee/module.h>
-#include <cherokee/table.h>
-#include <cherokee/buffer.h>
-
 
 CHEROKEE_BEGIN_DECLS
 
+
 /* Callback function definitions
  */
-typedef ret_t (* logger_func_new_t)          (void **logger, cherokee_table_t *properties);
+typedef ret_t (* logger_func_new_t)          (void **logger, cherokee_config_node_t *config);
 typedef ret_t (* logger_func_init_t)         (void  *logger);
 typedef ret_t (* logger_func_free_t)         (void  *logger);
 typedef ret_t (* logger_func_flush_t)        (void  *logger);
@@ -53,43 +51,49 @@ typedef ret_t (* logger_func_write_string_t) (void  *logger, const char *format)
 
 
 typedef struct {
-	/* Base
-	 */
-	cherokee_module_t module;
-
-	/* Private data
-	 */
+	cherokee_module_t               module;
 	struct cherokee_logger_private *priv;
 
 	/* Pure virtual methods
 	 */
-	logger_func_flush_t        flush;
-	logger_func_reopen_t       reopen;
-	logger_func_write_access_t write_access;
-	logger_func_write_error_t  write_error;
-	logger_func_write_string_t write_string;
-
-	/* Buffer 
-	 */
-	cherokee_buffer_t *buffer;
+	logger_func_flush_t             flush;
+	logger_func_reopen_t            reopen;
+	logger_func_write_access_t      write_access;
+	logger_func_write_error_t       write_error;
+	logger_func_write_string_t      write_string;
 
 } cherokee_logger_t;
 
-#define LOGGER(x)        ((cherokee_logger_t *)(x))
-#define LOGGER_BUFFER(b) (LOGGER(b)->buffer)
+#define LOGGER(x) ((cherokee_logger_t *)(x))
 
 
-ret_t cherokee_logger_init_base (cherokee_logger_t *logger);
+/* Easy initialization
+ */
+#define PLUGIN_INFO_LOGGER_EASY_INIT(name)                          \
+	PLUGIN_INFO_INIT(name, cherokee_logger,                     \
+		(void *)cherokee_logger_ ## name ## _new,           \
+		(void *)NULL)
 
-ret_t cherokee_logger_init  (cherokee_logger_t *logger);
-ret_t cherokee_logger_free  (cherokee_logger_t *logger);
+#define PLUGIN_INFO_LOGGER_EASIEST_INIT(name)                       \
+	PLUGIN_EMPTY_INIT_FUNCTION(name)                            \
+	PLUGIN_INFO_LOGGER_EASY_INIT(name)
 
-ret_t cherokee_logger_reopen (cherokee_logger_t *logger);
-ret_t cherokee_logger_flush  (cherokee_logger_t *logger);
 
-ret_t cherokee_logger_write_access (cherokee_logger_t *logger, void *conn);
-ret_t cherokee_logger_write_error  (cherokee_logger_t *logger, void *conn);
-ret_t cherokee_logger_write_string (cherokee_logger_t *logger, const char *format, ...);
+/* Logger methods
+ */
+ret_t cherokee_logger_init_base       (cherokee_logger_t *logger, cherokee_plugin_info_t *info);
+
+/* Logger virtual methods
+ */
+ret_t cherokee_logger_init            (cherokee_logger_t *logger);
+ret_t cherokee_logger_free            (cherokee_logger_t *logger);
+
+ret_t cherokee_logger_reopen          (cherokee_logger_t *logger);
+ret_t cherokee_logger_flush           (cherokee_logger_t *logger);
+
+ret_t cherokee_logger_write_access    (cherokee_logger_t *logger, void *conn);
+ret_t cherokee_logger_write_error     (cherokee_logger_t *logger, void *conn);
+ret_t cherokee_logger_write_string    (cherokee_logger_t *logger, const char *format, ...);
 
 ret_t cherokee_logger_set_backup_mode (cherokee_logger_t *logger, cherokee_boolean_t active);
 ret_t cherokee_logger_get_backup_mode (cherokee_logger_t *logger, cherokee_boolean_t *active);
