@@ -18,7 +18,8 @@ class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
         self.name             = "URL request I"
-        self.request          = "GET http://request1host/urlrequest1/dir/file HTTP/1.1\r\n"
+        self.request          = "GET http://request1host/urlrequest1/dir/file HTTP/1.1\r\n" + \
+                                "Connection: Close\r\n"
         self.expected_error   = 200
         self.expected_content = MAGIC
 
