@@ -1,8 +1,9 @@
 import os
 from base import *
 
-DIR  = "/SCGI3/"
-PORT = get_free_port()
+DIR    = "/SCGI3/"
+PORT   = get_free_port()
+PYTHON = look_for_python()
 
 SCRIPT = """
 from pyscgi import *
@@ -18,14 +19,18 @@ class TestHandler (SCGIHandler):
 SCGIServer(TestHandler, port=%d).serve_forever()
 """ % (PORT)
 
+source = get_next_source()
+
 CONF = """
 vserver!1!rule!1400!match = directory
-vserver!1!rule!1400!match!directory = <dir>
+vserver!1!rule!1400!match!directory = %(DIR)s
 vserver!1!rule!1400!handler = scgi
 vserver!1!rule!1400!handler!balancer = round_robin
-vserver!1!rule!1400!handler!balancer!type = interpreter
-vserver!1!rule!1400!handler!balancer!local_scgi3!host = localhost:%d
-vserver!1!rule!1400!handler!balancer!local_scgi3!interpreter = %s %s
+vserver!1!rule!1400!handler!balancer!source!1 = %(source)d
+
+source!%(source)d!type = interpreter
+source!%(source)d!host = localhost:%(PORT)d
+source!%(source)d!interpreter = %(PYTHON)s %(scgi_file)s
 """
 
 
@@ -46,5 +51,6 @@ class Test (TestBase):
         if not os.path.exists (pyscgi):
             self.CopyFile ('pyscgi.py', pyscgi)
 
-        self.conf = CONF % (PORT, look_for_python(), scgi_file)
-        self.conf = self.conf.replace ('<dir>', DIR)
+        vars = globals()
+        vars['scgi_file'] = scgi_file
+        self.conf = CONF % (vars)
